.. _polys-docs:

=======================
Polynomial Manipulation
=======================

Computations with polynomials are at the core of computer algebra and
having a fast and robust polynomials manipulation module is a key for
building a powerful symbolic manipulation system. SymPy has a dedicated
module :mod:`sympy.polys` for computing in polynomial algebras over
various coefficient domains.

There is a vast number of methods implemented, ranging from simple tools
like polynomial division, to advanced concepts including Gröbner bases
and multivariate factorization over algebraic number domains.

Contents
========

.. toctree::
   :titlesonly:

   basics.rst
   wester.rst
   reference.rst
   agca.rst
   domainsintro.rst
   domainsref.rst
   internals.rst
   ringseries.rst
   literature.rst
   solvers.rst
   domainmatrix.rst
   numberfields.rst
